@@ -63,16 +63,20 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} שיחזר את הקובץ המצורף {attachment} לכרטיס {card}",
     "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
     "{user} has commented on card {card}" : "נוספה תגובה מאת {user} על הכרטיס {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
     "Deck" : "חפיסה",
     "Changes in the <strong>Deck app</strong>" : "שינויים ל<strong>יישומון החבילה</strong>",
+    "A <strong>board, list or card</strong> was changed" : "לוח, רשימה או כרטיס שונה",
     "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
+    "A <strong>card description</strong> has been changed" : "תיאור הכרטיס שונה",
     "Upcoming cards" : "כרטיסים עתידיים",
+    "Load more" : "לטעון עוד",
     "Personal" : "אישי",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} has assigned the card {deck-card} on {deck-board} to you.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
     "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
+    "Deck board" : "לוח חסיפה",
     "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
     "Finished" : "הסתיים",
     "To review" : "לסקירה",
@@ -98,14 +102,15 @@ OC.L10N.register(
     "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם",
-    "Card details" : "פרטי הכרטיס",
     "Add board" : "הוספת לוח",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
+    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Select a board" : "נא לבחור לוח",
+    "No lists available" : "אין רשימות זמינות",
     "Select a list" : "בחר רשימה",
+    "Move card" : "העברת כרטיס",
     "Cancel" : "ביטול",
     "Select a card" : "נא לבחור כרטיס",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
@@ -125,6 +130,8 @@ OC.L10N.register(
     "Filter by tag" : "סינון לפי תגית",
     "Filter by assigned user" : "סינון לפי משתמש מוקצה",
     "Unassigned" : "לא הוקצה",
+    "Open" : "פתוח",
+    "Completed" : "הושלם",
     "Filter by due date" : "סינון לפי תאריך יעד",
     "Overdue" : "באיחור",
     "Next 24 hours" : "ב־24 השעות הבאות",
@@ -135,30 +142,28 @@ OC.L10N.register(
     "Hide archived cards" : "הסתרת כרטיסים בארכיון",
     "Show archived cards" : "הצגת כרטיסים בארכיון",
     "Toggle compact mode" : "החלפת מצב חסכוני",
+    "Open details" : "פתיחת פרטים",
     "Details" : "פרטים",
     "Loading board" : "הלוח נטען",
-    "No lists available" : "אין רשימות זמינות",
-    "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
     "Board not found" : "הלוח לא נמצא",
+    "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
     "Sharing" : "שיתוף",
     "Tags" : "תגיות",
     "Deleted items" : "פריטים שנמחקו",
-    "Timeline" : "ציר זמן",
+    "Activity" : "פעילות",
     "Deleted lists" : "רשימות שנמחקו",
     "Undo" : "ביטול",
     "Deleted cards" : "כרטיסים שנמחקו",
-    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
-    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
     "No participants found" : "לא נמצאו משתתפים",
     "Board owner" : "בעלות על הלוח",
     "(Group)" : "(קבוצה)",
-    "(Circle)" : "(מעגל)",
     "Can edit" : "ניתן לערוך",
     "Can share" : "Can share",
     "Can manage" : "הרשאת ניהול",
+    "Owner" : "בעלות",
     "Delete" : "מחיקה",
     "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
-    "Add a new list" : "הוסף רשימה חדשה",
+    "Transfer" : "העברה",
     "Archive all cards" : "ארכיב את כל הכרטיסים",
     "Delete list" : "מחיקת רשימה",
     "Archive all cards in this list" : "ארכיב את כל הכרטיסים ברשימה זו",
@@ -170,10 +175,12 @@ OC.L10N.register(
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Board name" : "שם הלוח",
     "Members" : "חברים",
+    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
     "Upload new files" : "העלאת קבצים חדשים",
     "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
     "Show in Files" : "הצגה בקבצים",
+    "Download" : "הורדה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
     "File to share" : "קובץ לשיתוף",
@@ -186,22 +193,13 @@ OC.L10N.register(
     "Created" : "מועד היצירה",
     "The title cannot be empty." : "הכותרת לא יכולה להיות ריקה.",
     "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
-    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
-    "Assign to users" : "הקצאה למשתמשים",
-    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
-    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
-    "Due date" : "מועד יעד",
-    "Set a due date" : "הגדרת תאריך יעד",
-    "Remove due date" : "הסרת מועד התפוגה",
-    "Select Date" : "בחירת תאריך",
-    "Today" : "היום",
-    "Tomorrow" : "מחר",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
     "In reply to" : "בתגובה אל",
     "Reply" : "תגובה",
     "Update" : "עדכון",
+    "Created:" : "מועד היצירה:",
     "Description" : "תיאור",
     "(Unsaved)" : "(לא נשמר)",
     "(Saving…)" : "(מתבצעת שמירה…)",
@@ -211,23 +209,29 @@ OC.L10N.register(
     "Add Attachment" : "הוספת קובץ מצורף",
     "Write a description …" : "כתוב תיאור ...",
     "Choose attachment" : "בחירת קובץ מצורף",
-    "(group)" : "(קבוצה)",
-    "Assign to me" : "הקצאה אלי",
-    "Unassign myself" : "לבטל את הקצאת עצמי",
-    "Move card" : "העברת כרטיס",
+    "Set a due date" : "הגדרת תאריך יעד",
+    "Remove due date" : "הסרת מועד התפוגה",
     "Unarchive card" : "הוצאת הכרטיס מהארכיון",
     "Archive card" : "העברת כרטיס לארכיון",
+    "Select Date" : "בחירת תאריך",
+    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
+    "(group)" : "(קבוצה)",
+    "Card details" : "פרטי הכרטיס",
+    "Assign to me" : "הקצאה אלי",
+    "Unassign myself" : "לבטל את הקצאת עצמי",
     "Delete card" : "מחיקת כרטיס לארכיון",
-    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Keyboard shortcut" : "קיצור מקלדת",
+    "Action" : "פעולה",
+    "Shift" : "הזזה",
+    "Search" : "חיפוש",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
     "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
     "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
-    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
     "Board details" : "פרטי לוח",
     "Edit board" : "עריכת לוח",
     "Clone board" : "שכפל את הלוח",
@@ -244,11 +248,14 @@ OC.L10N.register(
     "Only assigned cards" : "רק כרטיסים שהוקצו",
     "No reminder" : "אין תזכורת",
     "An error occurred" : "אירעה שגיאה",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
     "Delete the board?" : "למחוק את הלוח הזה?",
     "Loading filtered view" : "טוען תצוגה מסוננת",
-    "This week" : "השבוע",
+    "Today" : "היום",
+    "Tomorrow" : "מחר",
     "No due" : "אין תאריך יעד",
+    "No results found" : "לא נמצאו תוצאות",
+    "Create card" : "יצירת כרטיס",
+    "Close" : "סגירה",
     "No upcoming cards" : "אין כרטיסים עתידיים",
     "upcoming cards" : "כרטיסים עתידיים",
     "Link to a board" : "קישור ללוח",
@@ -259,6 +266,17 @@ OC.L10N.register(
     "Error creating the share" : "שגיאה ביצירת השיתוף",
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
-    "Share" : "שיתוף"
+    "Share" : "שיתוף",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
+    "Timeline" : "ציר זמן",
+    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
+    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
+    "(Circle)" : "(מעגל)",
+    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
+    "Next week" : "השבוע הבא",
+    "Next month" : "החודש הבא",
+    "List is empty" : "הרשימה ריקה",
+    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם."
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
