@@ -63,18 +63,32 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に復元しました",
     "You have commented on card {card}" : "カード{card}にコメントしました",
     "{user} has commented on card {card}" : "{user}がカード{card}にコメントしました",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
     "Deck" : "デッキ",
     "Changes in the <strong>Deck app</strong>" : "<strong>デッキアプリ</strong>に変更があったとき",
+    "A <strong>board, list or card</strong> was changed" : "<strong>ボード、リストまたはカードは変更されました",
     "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
+    "A <strong>card description</strong> has been changed" : "<strong>カード説明</strong>が変更されました",
+    "Cards due today" : "今日の期限切れのカード",
+    "Cards due tomorrow" : "明日の期限切れのカード",
     "Upcoming cards" : "今後のカード",
+    "Load more" : "さらに読み込む",
     "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} さんが、{deck-board} で、あなたにカード「{deck-card}」を割り当てました。",
     "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
+    "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board}上のカード「{deck-card}」は、期日を迎えました。",
     "%s has mentioned you in a comment on \"%s\"." : "%sさんは \"%s\"へのコメントであなたについて言及しました。",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} さんが 「{deck-card}」のコメント内であなたについて言及しました。",
     "The board \"%s\" has been shared with you by %s." : "\"%s\" ボードは、%s からあなたに共有されています。",
+    "{user} has shared {deck-board} with you." : "{user} さんが、あなたと {deck-board} を共有しました。",
+    "Deck board" : "Deckボード",
+    "Owned by %1$s" : "%1$sが所有している",
+    "Deck boards, cards and comments" : "デッキボード、カードとコメント",
+    "From %1$s, in %2$s/%3$s, owned by %4$s" : "%1$sより、%2$s/%3$s,%4$sの所有",
+    "Create a new deck card" : "新しいデッキカードを作成",
     "Card comments" : "カードコメント",
     "%s on %s" : "%s が %s で",
+    "Deck boards and cards" : "デッキボードとカード",
     "No data was provided to create an attachment." : "添付ファイルを作成するためのデータは提供されていません。",
     "Finished" : "完了",
     "To review" : "レビューする",
@@ -96,24 +110,22 @@ OC.L10N.register(
     "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
     "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
     "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
+    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "このコメントは、%s 文字以上含まれています。\n%sという名前で、カードに添付ファイルとして追加しました。\n次のURLでアクセス可能です: %s",
     "Card not found" : "カードが見つかりません",
     "Path is already shared with this card" : "パスは既にこのカードで共有されています",
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
-    "Card details" : "カード詳細",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
     "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
-    "Create a new card" : "新しいカードを作成する",
+    "Move card to another board" : "カードを他のボードに移動",
     "Select a board" : "ボードを選択",
+    "No lists available" : "利用可能なリストはありません",
     "Select a list" : "リストを選択",
-    "Card title" : "カードのタイトル",
+    "Move card" : "カードの移動",
     "Cancel" : "キャンセル",
-    "Open card" : "カードを開く",
-    "Close" : "閉じる",
-    "Create card" : "カードを作成",
     "Select a card" : "カードを選択",
     "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
     "Link to card" : "カードへリンク",
@@ -128,10 +140,14 @@ OC.L10N.register(
     "Archived cards" : "カードをアーカイブ",
     "Add list" : "リストを追加",
     "List name" : "リスト名",
+    "Active filters" : "有効なフィルター",
     "Apply filter" : "フィルターを適用",
     "Filter by tag" : "タグによるフィルター",
     "Filter by assigned user" : "割当ユーザーでフィルター",
     "Unassigned" : "未割り当て",
+    "Open and completed" : "開いて完成",
+    "Open" : "開く",
+    "Completed" : "完了",
     "Filter by due date" : "期限でフィルター",
     "Overdue" : "期限超過",
     "Next 24 hours" : "次の24時間",
@@ -139,36 +155,49 @@ OC.L10N.register(
     "Next 30 days" : "次の30日間",
     "No due date" : "期限なし",
     "Clear filter" : "フィルターをクリア",
+    "View Modes" : "表示モード",
+    "Toggle View Modes" : "表示モードを切り替える",
     "Hide archived cards" : "アーカイブされたカードを非表示にする",
     "Show archived cards" : "アーカイブされたカードを表示する",
     "Toggle compact mode" : "コンパクトモードの切り替え",
+    "Hide card cover images" : "カードの画像を非表示にする",
+    "Show card cover images" : "カードの画像を表示する",
+    "Open details" : "詳細を開く",
     "Details" : "詳細",
+    "Currently present people" : "現在出席している人々",
     "Loading board" : "ボードを読み込み中",
-    "No lists available" : "利用可能なリストはありません",
-    "Create a new list to add cards to this board" : "このボードにカードを追加するための新しいリストを作成します",
     "Board not found" : "ボードが見つかりません",
+    "Create a new list to add cards to this board" : "このボードにカードを追加するための新しいリストを作成します",
     "Sharing" : "共有中",
     "Tags" : "タグ",
     "Deleted items" : "削除されたアイテム",
-    "Timeline" : "タイムライン",
+    "Activity" : "アクティビティ",
     "Deleted lists" : "削除済みリスト",
     "Undo" : "元に戻す",
     "Deleted cards" : "削除済みのカード",
-    "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
-    "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
+    "Share board with a user, group or team …" : "ユーザー、グループ、チームでボードを共有 ...",
+    "Searching for users, groups and teams …" : "ユーザー、グループ、チームの検索中...",
     "No participants found" : "参加者が見つかりません",
     "Board owner" : "ボード所有者",
     "(Group)" : "(グループ)",
-    "(Circle)" : "(サークル)",
+    "(Team)" : "(チーム)",
     "Can edit" : "編集可能",
     "Can share" : "共有可能",
     "Can manage" : "管理可能",
+    "Owner" : "所有者",
     "Delete" : "削除",
     "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
-    "Add a new list" : "新しいリストを追加",
+    "Are you sure you want to transfer the board {title} to {user}?" : "本当にボード {title} を {user} に転送しますか？",
+    "Transfer the board." : "ボードを転送します。",
+    "Transfer" : "転送",
+    "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
+    "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
+    "Edit list title" : "リストタイトルを編集する",
     "Archive all cards" : "すべてのカードをアーカイブする",
+    "Unarchive all cards" : "全てのカードをアーカイブ解除",
     "Delete list" : "リストを削除",
     "Archive all cards in this list" : "このリストのすべてのカードをアーカイブする",
+    "Unarchive all cards in this list" : "このリスト内の全てのカードのアーカイブを解除する",
     "Add a new card" : "新しいカードを追加",
     "Card name" : "カード名",
     "List deleted" : "リストが削除されました",
@@ -177,10 +206,16 @@ OC.L10N.register(
     "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
     "Board name" : "ボード名",
     "Members" : "メンバー",
+    "Assign to users/groups/team" : "ユーザー/グループ/チームに割り当てる",
+    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
+    "Select a user to assign to this card…" : "このカードに割り当てるユーザーを選択してください。",
     "Upload new files" : "新しいファイルをアップロード",
     "Share from Files" : "ファイルから共有",
+    "Pending share" : "共有を保留中",
     "Add this attachment" : "この添付ファイルを追加",
     "Show in Files" : "ファイルに表示",
+    "Download" : "ダウンロード",
+    "Remove attachment" : "添付ファイルを削除",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
     "File to share" : "共有するファイル",
@@ -193,22 +228,15 @@ OC.L10N.register(
     "Created" : "作成時刻",
     "The title cannot be empty." : "タイトルを空にすることはできません。",
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
-    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
-    "Assign to users" : "ユーザーに割り当てる",
-    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
-    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
-    "Due date" : "期限",
-    "Set a due date" : "期限を設定",
-    "Remove due date" : "期限を削除",
-    "Select Date" : "日付を選択",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
+    "Failed to load comments" : "コメントの読み込みに失敗しました",
     "Save" : "保存",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
     "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
     "In reply to" : "返信",
+    "Cancel reply" : "返信をキャンセル",
     "Reply" : "返信",
     "Update" : "更新",
+    "Created:" : "作成:",
     "Description" : "説明",
     "(Unsaved)" : "(未保存)",
     "(Saving…)" : "(保存中…)",
@@ -218,28 +246,76 @@ OC.L10N.register(
     "Add Attachment" : "添付ファイルを追加",
     "Write a description …" : "説明を書く…",
     "Choose attachment" : "添付ファイルを選択",
-    "(group)" : "(グループ)",
-    "Assign to me" : "自分に割り当てる",
-    "Unassign myself" : "自分への割り当てを解除",
-    "Move card" : "カードの移動",
+    "Assign a due date to this card…" : "このカードの期限を割り当てる",
+    "Set a due date" : "期限を設定",
+    "Add due date" : "期限日を追加する",
+    "Choose a date" : "日時を選択する",
+    "Remove due date" : "期限を削除",
+    "Mark as done" : "完了としてマーク",
+    "Due at:" : "期限:",
+    "Not done" : "まだ完成していません",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
+    "Select Date" : "日付を選択",
+    "Set due date for later today" : "期限を今日中に設定する",
+    "Set due date for tomorrow" : "期限を明日の設定する",
+    "Set due date for this weekend" : "期限を今週の週末に設定する",
+    "Set due date for next week" : "期限を次の週の設定する",
+    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
+    "Select or create a tag…" : "タグを選択または作成する",
+    "Create a new tag:" : "新しいタグを作成:",
+    "(group)" : "(グループ)",
+    "Next week – {timeLocale}" : "来週 – {timeLocale}",
+    "Todo items" : "Todo項目",
+    "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
+    "Edit card title" : "カードタイトルを編集する",
+    "Card details" : "カード詳細",
+    "Assign to me" : "自分に割り当てる",
+    "Unassign myself" : "自分への割り当てを解除",
+    "Mark as not done" : "未完成のマーク",
     "Delete card" : "カードを削除する",
-    "Move card to another board" : "カードを他のボードに移動",
     "Card deleted" : "カードが削除されました",
     "seconds ago" : "数秒前",
+    "Keyboard shortcuts" : "キーボードショートカット",
+    "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
+    "Board actions" : "ボードアクション",
+    "Keyboard shortcut" : "キーボードショートカット",
+    "Action" : "アクション",
+    "Shift" : "Shift",
+    "Scroll" : "スクロール",
+    "Scroll sideways" : "横にスクロール",
+    "Navigate between cards" : "カード間を移動する",
+    "Esc" : "Esc",
+    "Close card details" : "カードの詳細を閉じる",
+    "Ctrl" : "Ctrl",
+    "Search" : "検索",
+    "Show card filters" : "カードフィルターを表示",
+    "Clear card filters" : "カードフィルターを削除",
+    "Show help dialog" : "ヘルプダイアログを表示",
+    "Card actions" : "カードアクション",
+    "The following actions can be triggered on the currently highlighted card" : "現在ハイライトされているカードに対して以下のアクションを起こすことができる。",
+    "Enter" : "Enter",
+    "Space" : "スペース",
+    "Open card details" : "カードの詳細を開く",
+    "Edit the card title" : "カードタイトルを編集する",
+    "Assign yourself to the current card" : "カードを自分に割り当てる",
+    "Archive/unarchive the current card" : "現在のカードをアーカイブ/アーカイブ解除",
+    "Mark card as completed/not completed" : "カードを完了/未完了にマークする",
+    "Open card menu" : "カードメニューを開く",
     "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
+    "Deck settings" : "デック設定",
     "Use bigger card view" : "大きなカードビューを使用する",
+    "Show card ID badge" : "カードIDバジを表示",
     "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
-    "Limit deck usage of groups" : "デッキの使用をグループに制限",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
+    "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
     "Clone board" : "ボードを複製",
     "Unarchive board" : "ボードのアーカイブを解除",
     "Archive board" : "ボードをアーカイブ",
+    "Export board" : "ボードをエクスポートする",
     "Turn on due date reminders" : "期日のリマインダーをオンにする",
     "Turn off due date reminders" : "期日のリマインダーをオフにする",
     "Due date reminders" : "期日のリマインダー",
@@ -251,15 +327,34 @@ OC.L10N.register(
     "Only assigned cards" : "割り当てられたカードのみ",
     "No reminder" : "リマインダーなし",
     "An error occurred" : "エラーが発生しました",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
     "Delete the board?" : "ボードを削除しますか？",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
-    "This week" : "今週",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
     "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
+    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
+    "Deck board {name}\n* Last modified on {lastMod}" : "デッキボード{name}\n最終更新日：{lastMod}",
+    "{stack} in {board}" : "{board} 内の {stack}",
+    "Click to expand description" : "説明を展開するにはクリックしてください",
+    "{nbCards} cards" : "{nbCards} カード",
+    "Click to expand comment" : "コメントを展開するにはクリックしてください",
+    "Create a new card" : "新しいカードを作成する",
+    "Card title" : "カードのタイトル",
+    "Create card" : "カードを作成",
+    "Creating the new card …" : "新しいカードを作成しています...",
+    "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
+    "Open card" : "カードを開く",
+    "Close" : "閉じる",
     "No upcoming cards" : "今後のカードはありません",
+    "upcoming cards today" : "今日の予定のカード",
+    "upcoming cards tomorrow" : "明日の予定のカード",
     "upcoming cards" : "今後のカード",
+    "New card" : "新しいカード",
+    "Due on {date}" : "期間{date}",
+    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
+    "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
     "Link to a board" : "ボードへのリンク",
     "Link to a card" : "カードへリンク",
     "Create a card" : "カードを作成",
@@ -270,6 +365,19 @@ OC.L10N.register(
     "Error creating the share" : "共有の作成中にエラーが発生しました",
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
-    "Share" : "共有"
+    "Share" : "共有",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
+    "Timeline" : "タイムライン",
+    "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
+    "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
+    "(Circle)" : "(サークル)",
+    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
+    "Next week" : "来週",
+    "Next month" : "来月",
+    "List is empty" : "リストが空です",
+    "Limit deck usage of groups" : "デッキの使用をグループに制限",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
+    "Not completed" : "完成してないです",
+    "Filter by completed" : "完成したものをフィルターする"
 },
 "nplurals=1; plural=0;");
