@@ -63,11 +63,11 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovi prilogo {attachment} naloge {card}",
     "You have commented on card {card}" : "Vpišete opombo k nalogi {card}",
     "{user} has commented on card {card}" : "{user} vpiše opombo k nalogi {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
     "Upcoming cards" : "Prihajajoče naloge",
+    "Load more" : "Naloži več",
     "Personal" : "Osebno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam dodeli nalogo »{deck-card}« na »{deck-board}«.",
@@ -77,6 +77,7 @@ OC.L10N.register(
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vas omeni v opombi na »{deck-card}«.",
     "The board \"%s\" has been shared with you by %s." : "Zbirko »%s« vam dodeli %s.",
     "{user} has shared {deck-board} with you." : "{user} vam omogoča souporabo zbirke {deck-board}.",
+    "Deck board" : "Zbirka Deck",
     "Card comments" : "Opombe k nalogi",
     "%s on %s" : "%s v nalogi %s",
     "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
@@ -104,22 +105,16 @@ OC.L10N.register(
     "Path is already shared with this card" : "Pot je že povezana s to nalogo",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
     "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
-    "Card details" : "Podrobnosti naloge",
     "Add board" : "Dodaj zbirko",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
     "Select board" : "Izbor zbirke",
-    "Create a new card" : "Ustvari novo nalogo",
+    "Move card to another board" : "Premakni nalogo v drugo zbirko",
     "Select a board" : "Izbor zbirke",
+    "No lists available" : "Ni razpoložljivih seznamov",
     "Select a list" : "Izbor seznama",
-    "Card title" : "Naslov naloge",
+    "Move card" : "Premakni nalogo",
     "Cancel" : "Prekliči",
-    "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
-    "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
-    "Open card" : "Odpri nalogo",
-    "Close" : "Zapri",
-    "Create card" : "Ustvari nalogo",
     "Select a card" : "Izbor naloge",
     "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
     "Link to card" : "Poveži nalogo",
@@ -138,6 +133,8 @@ OC.L10N.register(
     "Filter by tag" : "Filtriraj po oznaki",
     "Filter by assigned user" : "Filtriraj po dodeljenem uporabniku",
     "Unassigned" : "Nedodeljeno",
+    "Open" : "Odpri",
+    "Completed" : "Končano",
     "Filter by due date" : "Filtriraj po datumu preteka",
     "Overdue" : "Preteklo",
     "Next 24 hours" : "Naslednjih 24 ur",
@@ -148,30 +145,28 @@ OC.L10N.register(
     "Hide archived cards" : "Skrij arhivirane naloge",
     "Show archived cards" : "Prikaži arhivirane naloge",
     "Toggle compact mode" : "Preklopi način prikaza",
+    "Open details" : "Odpri podrobnosti",
     "Details" : "Podrobnosti",
     "Loading board" : "Poteka nalaganje zbirke",
-    "No lists available" : "Ni razpoložljivih seznamov",
-    "Create a new list to add cards to this board" : "Ustvari nov seznam in doda kartice v zbirko",
     "Board not found" : "Zbirke ni mogoče najti",
+    "Create a new list to add cards to this board" : "Ustvari nov seznam in doda kartice v zbirko",
     "Sharing" : "Souporaba",
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisani predmeti",
-    "Timeline" : "Časovnica",
+    "Activity" : "Dejavnost",
     "Deleted lists" : "Izbrisani seznami",
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
-    "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
-    "Searching for users, groups and circles …" : "Iskanje uporabnikov, skupin in krogov ...",
     "No participants found" : "Ni zaznanih udeleženev",
     "Board owner" : "Lastnik zbirke",
     "(Group)" : "(Skupina)",
-    "(Circle)" : "(Krog)",
     "Can edit" : "Lahko ureja",
     "Can share" : "Lahko omogoči souporabo",
     "Can manage" : "Lahko upravlja",
+    "Owner" : "Lastnik",
     "Delete" : "Izbriši",
     "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
-    "Add a new list" : "Dodaj nov seznam",
+    "Transfer" : "Prenos",
     "Archive all cards" : "Arhiviraj vse kartice",
     "Delete list" : "Izbriši seznam",
     "Archive all cards in this list" : "Arhiviraj vse kartice tega seznama",
@@ -181,12 +176,14 @@ OC.L10N.register(
     "Edit" : "Uredi",
     "Add a new tag" : "Dodaj novo oznako",
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
-    "Board name" : "Ime  zbirke",
+    "Board name" : "Ime zbirke",
     "Members" : "Člani",
+    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
     "Upload new files" : "Pošlji nove datoteke",
     "Share from Files" : "Poveži iz oblaka",
     "Add this attachment" : "Dodaj prilogo",
     "Show in Files" : "Poveži iz oblaka",
+    "Download" : "Prejmi",
     "Remove attachment" : "Odstrani prilogo",
     "Delete Attachment" : "Izbriši prilogo",
     "Restore Attachment" : "Obnovi prilogo",
@@ -201,16 +198,6 @@ OC.L10N.register(
     "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
     "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
     "Failed to load comments" : "Nalaganje opomb je spodletelo.",
-    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
-    "Assign to users" : "Dodeli uporabnikom",
-    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
-    "Assign a user to this card…" : "Dodeli uporabnika k nalogi ...",
-    "Due date" : "Datum preteka",
-    "Set a due date" : "Nastavi datum preteka",
-    "Remove due date" : "Odstrani datum preteka",
-    "Select Date" : "Izbor datuma",
-    "Today" : "Danes",
-    "Tomorrow" : "Jutri",
     "Save" : "Shrani",
     "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
     "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
@@ -218,6 +205,7 @@ OC.L10N.register(
     "Cancel reply" : "Prekliči odgovor",
     "Reply" : "Odgovori",
     "Update" : "Posodobi",
+    "Created:" : "Ustvarjeno:",
     "Description" : "Opis",
     "(Unsaved)" : "(neshranjeno)",
     "(Saving…)" : "(shranjevanje ...)",
@@ -227,24 +215,60 @@ OC.L10N.register(
     "Add Attachment" : "Dodaj prilogo",
     "Write a description …" : "Vpišite opis ...",
     "Choose attachment" : "Izbor priloge",
-    "(group)" : "(skupina)",
-    "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
-    "Assign to me" : "Nalogo dodeli meni",
-    "Unassign myself" : "Odstrani me z naloge",
-    "Move card" : "Premakni nalogo",
+    "Set a due date" : "Nastavi datum preteka",
+    "Add due date" : "Dodaj datum preteka",
+    "Choose a date" : "Izbor datuma",
+    "Remove due date" : "Odstrani datum preteka",
+    "Mark as done" : "Označi kot končano",
+    "Due at:" : "Poteče:",
+    "Not done" : "Ni končano",
     "Unarchive card" : "Povrni nalogo",
     "Archive card" : "Arhiviraj nalogo",
+    "Select Date" : "Izbor datuma",
+    "Set due date for later today" : "Nastavi datum preteka na danes kasneje",
+    "Set due date for tomorrow" : "Nastavi datum preteka na jutri",
+    "Set due date for this weekend" : "Nastavi datum preteka na ta teden",
+    "Set due date for next week" : "Nastavi datum preteka na naslednji teden",
+    "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
+    "Select or create a tag…" : "Izberi ali ustvari oznako ...",
+    "Create a new tag:" : "Ustvari novo oznako:",
+    "(group)" : "(skupina)",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
+    "Todo items" : "Naloge",
+    "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
+    "Edit card title" : "Uredi naslov naloge",
+    "Card details" : "Podrobnosti naloge",
+    "Assign to me" : "Nalogo dodeli meni",
+    "Unassign myself" : "Odstrani me z naloge",
+    "Mark as not done" : "Označi kot Ni končano",
     "Delete card" : "Izbriši nalogo",
-    "Move card to another board" : "Premakni nalogo v drugo zbirko",
     "Card deleted" : "Naloga je izbrisana",
     "seconds ago" : "pred nekaj sekundami",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Boost your productivity using Deck with keyboard shortcuts." : "Povečaj hitrost dela z uporabo tipkovnih bližnjic",
+    "Keyboard shortcut" : "Tipkovna bližnjica",
+    "Action" : "Dejanje",
+    "Shift" : "Premakni",
+    "Scroll" : "Zdrsni",
+    "Scroll sideways" : "Zdrsni bočno",
+    "Navigate between cards" : "Krmarjenje med nalogami",
+    "Esc" : "Esc",
+    "Close card details" : "Zapri podrobnosti kartice",
+    "Ctrl" : "CTRL",
+    "Search" : "Poišči",
+    "Show card filters" : "Pokaži filtre kartice",
+    "Clear card filters" : "Počisti filtre kartice",
+    "Show help dialog" : "Pokaži okno pomoči",
+    "Card actions" : "Dejanja naloge",
+    "Enter" : "Vnos",
+    "Space" : "Presledek",
+    "Open card details" : "Odpri podrobnosti naloge",
+    "Edit the card title" : "Uredi naslov naloge",
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
     "Shared with you" : "V souporabi z vami",
     "Use bigger card view" : "Uporabi povečan pogled nalog",
     "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
-    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
     "Clone board" : "Kloniraj zbirko",
@@ -261,15 +285,29 @@ OC.L10N.register(
     "Only assigned cards" : "Le dodeljene naloge",
     "No reminder" : "Ni vpisanih opomnikov",
     "An error occurred" : "Prišlo je do napake.",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
-    "This week" : "Ta teden",
+    "Today" : "Danes",
+    "Tomorrow" : "Jutri",
     "No due" : "Ni datuma preteka",
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
+    "{stack} in {board}" : "{stack} v {board}",
+    "Click to expand comment" : "Kliknite za razširitev opombe",
+    "Create a new card" : "Ustvari novo nalogo",
+    "Card title" : "Naslov naloge",
+    "Create card" : "Ustvari nalogo",
+    "Creating the new card …" : "Poteka ustvarjanje nove naloge ...",
+    "Card \"{card}\" was added to \"{board}\"" : "Naloga »{card}« je dodana v zbirko »{board}«.",
+    "Open card" : "Odpri nalogo",
+    "Close" : "Zapri",
     "No upcoming cards" : "Ni prihajajočih nalog",
     "upcoming cards" : "prihajajoče naloge",
+    "New card" : "Nova naloga",
+    "Due on {date}" : "Poteče {date}",
+    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
+    "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Create a card" : "Ustvari nalogo",
@@ -279,6 +317,19 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Omejitev velikosti datoteke {size} je prekoračena.",
     "Error creating the share" : "Napaka ustvarjanja mesta souporabe",
     "Share with a Deck card" : "Poveži z nalogo Deck",
-    "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck"
+    "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
+    "Share" : "Souporaba",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
+    "Timeline" : "Časovnica",
+    "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
+    "Searching for users, groups and circles …" : "Iskanje uporabnikov, skupin in krogov ...",
+    "(Circle)" : "(Krog)",
+    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
+    "Next week" : "Naslednji teden",
+    "Next month" : "Naslednji mesec",
+    "List is empty" : "Seznam je prazen",
+    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
+    "Not completed" : "Ni končano"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
