@@ -10,14 +10,20 @@ OC.L10N.register(
     "Tags" : "بەلگەلەر",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
+    "Owner" : "Owner",
     "Delete" : "ئۆچۈر",
     "Edit" : "تەھرىر",
+    "Download" : "چۈشۈر",
     "Modified" : "ئۆزگەرتكەن",
-    "Today" : "بۈگۈن",
     "Save" : "ساقلا",
     "Reply" : "جاۋاب قايتۇر",
     "Update" : "يېڭىلا",
+    "Created:" : "قۇرۇلغان ۋاقتى:",
     "Description" : "چۈشەندۈرۈش",
-    "Shared with you" : "Shared with you"
+    "Search" : "Search",
+    "Shared with you" : "Shared with you",
+    "Today" : "بۈگۈن",
+    "Close" : "ياپ",
+    "Share" : "ھەمبەھىر"
 },
 "nplurals=2; plural=(n != 1);");
